package org.broad.igv.event;

/**
 * Created by jrobinso on 2/7/17.
 */
public final class GenomeResetEvent implements IGVEvent {
}
